@@ -40,10 +40,11 @@ use JSON qw();
 use URI::Encode qw(uri_encode);
 use POSIX qw(strftime);
 
-our $VERSION=1.14;
+our $VERSION=1.15;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
+use constant TIMESTAMP_FORMAT=>'%m/%d/%Y %H:%M:%S';
 use Net::SolarWinds::Result;
 
 
@@ -202,14 +203,8 @@ sub NodeUnmanage {
   my ($self,$nodeid,$start,$end,$state)=@_;
   my $id='N:'.$nodeid;
 
-  my $format='%m/%d/%Y %H:%M:%S';
-  $start=strftime($format,localtime) unless defined($start);
-  unless(defined($end)) {
-    my $now=time;
-    # 10 years from now!
-    $now +=60 * 60 * 24 * 365 * 10;
-    $end=strftime($format,localtime) 
-  }
+  $start=$self->now_timestamp unless defined($start);
+  $end=$self->future_timestamp unless defined($end);
   $state=JSON::true unless defined($state);
   my $request=$self->build_request('POST','Invoke/Orion.Nodes/Unmanage',[$id,$start,$end,$state]);
   my $result=$self->run_request($request);
@@ -217,6 +212,33 @@ sub NodeUnmanage {
   return $result;
 }
 
+=item * my $now=$self->now_timestamp;
+
+Returns a timestamp of now.
+
+=cut
+
+sub now_timestamp {
+  my ($self)=@_;
+  my $now=strftime($self->TIMESTAMP_FORMAT,localtime);
+  return $now;
+}
+
+=item * my $future=$self->future_timestamp;
+
+Returns a timestamp of 10 years for now ( plus or minus a few seconds )
+
+=cut
+
+sub future_timestamp {
+  my ($self)=@_;
+  my $now=time;
+  # 10 years from now!
+  $now +=60 * 60 * 24 * 365 * 10;
+  my $ts=strftime($self->TIMESTAMP_FORMAT,localtime($now));
+  return $ts;
+}
+
 =item * my $result=$self->run_request($request);
 
 Takes a given HTTP::Request object and runs it returing a Net::SolarWinds::Result object.
@@ -286,7 +308,7 @@ sub DiscoverInterfaceMap {
   return $self->build_interface_result_map($result);
 }
 
-=item my $result=$self->build_interface_result_map($result);
+=item * my $result=$self->build_interface_result_map($result);
 
 Internals of DiscoverInterfaceMap
 
@@ -1109,7 +1131,7 @@ sub GetNodePollers {
   return $self->RESULT_CLASS->new_true($pollers);
 }
 
-=item my $result=$self->UpdateUri($uri,%args);
+=item * my $result=$self->UpdateUri($uri,%args);
 
 Read/Write Interface used update or get the contents of $uri.  Returns a Net::SolarWinds::Result object.  Write Mode is used when %args contains values Read Mode is used when %args is empty
 
